import React, { Component } from 'react';
import PropTypes from 'prop-types';
import {
  StyleSheet,
  Text,
  TextInput,
  View,
  Animated,
  TouchableWithoutFeedback,
  TouchableOpacity,
  PixelRatio,
  Platform,
  Image
} from 'react-native'


class FloatingLabel extends Component {
  constructor(props) {
    super(props);
    this.state = {
      fieldFocused: (props.value) ? true : false,
      value: (props.value) ? String(props.value) : undefined,
      fadeAnim: (props.value) ? new Animated.Value(1) : new Animated.Value(0),
      borderBottomWidth: 1.5
    };
    this._onChangeText.bind(this);
    this._onBlur.bind(this);
    this._onFocus.bind(this);
  }

  componentWillReceiveProps(props) {
    if (props.hasOwnProperty("value"))
      if (props.value != this.state.value) {
        this.setState({
          value: props.value,
          fadeAnim: (props.value) ? new Animated.Value(1) : new Animated.Value(0),
        });
      }
  }

  render() {
    const label =
      <Animated.Text style={[this.props.labelStyle, {
        opacity: this.state.fadeAnim,
        transform: [{
          translateY: this.state.fadeAnim.interpolate({
            inputRange: [0, 1],
            outputRange: [6, 0]
          }),
        }]
      }]}>
        {this.props.placeholder}
      </Animated.Text>

    let ViewText;
    if (this.props.editable == false)
      ViewText = View;
    else ViewText = TouchableOpacity;
    let fontSize = 15;
    if (this.props.inputStyle) {
      let style = StyleSheet.flatten(this.props.inputStyle);
      if (style)
        fontSize = style.fontSize || fontSize;
    }

    fontSize = (this.props.textSize || fontSize || 15) / PixelRatio.getFontScale();
    console.log(this.props.textContentType)
    return (
      <ViewText
        onPress={() => {
          if (this.props.editable === false) {
            if (this.props.onPress)
              this.props.onPress();
          }
          this.refs.input.focus()
        }}>
        {label}
        <View style={this.props.style}>
        {this.props.leftIcon}
          <TextInput
            ref='input'
            pointerEvents={this.props.editable == false ? "none" : "auto"}
            onBlur={() => this._onBlur()}
            onFocus={() => this._onFocus()}
            onChangeText={(x) => this._onChangeText(x)}
            placeholder={this.state.fieldFocused ? '' : this.props.placeholder}
            autoCapitalize={this.props.autoCapitalize}
            autoComplete={this.props.textContentType}
            importantForAutofill="yes"
            autoCompleteType={this.props.textContentType}
            textContentType={this.props.textContentType}
            autoFocus={this.props.autoFocus}
            bufferDelay={this.props.bufferDelay}
            clearButtonMode={this.props.clearButtonMode}
            editable={this.props.editable}
            enablesReturnKeyAutomatically={this.props.enablesReturnKeyAutomatically}
            keyboardType={this.props.keyboardType}
            multiline={this.props.multiline}
            onEndEditing={this.props.onEndEditing}
            onSubmitEditing={this.props.onSubmitEditing}
            returnKeyType={this.props.returnKeyType}
            selectTextOnFocus={this.props.selectTextOnFocus}
            secureTextEntry={this.props.secureTextEntry}
            selectionState={this.props.selectionState}
            maxLength={this.props.maxLength}
            numberOfLines={this.props.numberOfLines}
            textAlign={this.props.textAlign}
            textAlignVertical={this.props.textAlignVertical}
            underlineColorAndroid={this.props.underlineColorAndroid ? this.props.underlineColorAndroid : "transparent"}
            style={[styles.textInput, {
              borderBottomWidth: this.state.borderBottomWidth,
              borderBottomColor: this.props.underlineColor,
              color: this.props.textColor,
              paddingLeft: 0, paddingRight: 0,
              fontSize: this.props.textSize
            }, this.props.inputStyle, this.state.fieldFocused ? {} : this.state.value ? {} : this.props.placeholderStyle, Platform.OS == 'android' ? { fontSize: fontSize } : {}]}
            value={this.state.value}
          />
        </View>
      </ViewText>
    )
  }



  _onChangeText(text) {
    this.setState({ value: text });
    if (this.props.onChangeText) {
      this.props.onChangeText(text);
    }
  }

  _onFocus() {
    if (this.props.onFocus)
      this.props.onFocus();
    Animated.spring(
      this.state.fadeAnim,
      { toValue: 1, friction: 5 },
    ).start();
    this.setState({
      fieldFocused: true,
      borderBottomWidth: 2
    });
  }

  _onBlur() {
    if (this.props.onFocus)
      this.props.onFocus();
    if (!this.state.value) {
      Animated.timing(
        this.state.fadeAnim,
        { toValue: 0 },
      ).start();
    }
    this.setState({
      fieldFocused: false,
      borderBottomWidth: 1.5
    });
  }

  shouldComponentUpdate(nextProps, nextState) {
    return true;
  }
}
FloatingLabel.propTypes = {
  onTextChange: PropTypes.func,
};
const styles = StyleSheet.create({
  textInput: {
    height: 40,
  }
});

export default FloatingLabel
